@@ -1,5 +1,6 @@
+# -*- coding: utf-8 -*-
+from __future__ import unicode_literals
 from __future__ import print_function
-
 import sys
 import uuid
 import datetime
@@ -24,9 +25,6 @@ _serializers = dict({})
 
 
 class TaggedElement(object):
-    def __init__(self, name, value):
-        raise NotImplementedError("To be implemented by derived classes")
-
     def __str__(self):
         raise NotImplementedError("To be implemented by derived classes")
 
@@ -93,9 +91,9 @@ def p_map(p):
     """map : MAP_START expressions MAP_OR_SET_END"""
     terms = p[2]
     if len(terms) % 2 != 0:
-        raise SyntaxError("Even number of terms required for map")
+        raise SyntaxError('Even number of terms required for map')
     # partition terms in pairs
-    p[0] = ImmutableDict(dict([terms[i:i+2] for i in range(0, len(terms), 2)]))
+    p[0] = ImmutableDict(dict([terms[i:i + 2] for i in range(0, len(terms), 2)]))
 
 
 def p_expressions_expressions_expression(p):
@@ -123,12 +121,12 @@ def p_expression_tagged_element(p):
     element = p[2]
 
     if tag == 'inst':
-        if len(element) == 10 and element.count("-") == 2:
-            output = datetime.datetime.strptime(element, "%Y-%m-%d").date()
-        elif len(element) == 7 and element.count("-") == 1:
-            output = datetime.datetime.strptime(element, "%Y-%m").date()
-        elif len(element) == 4 and element.count("-") == 0:
-            output = datetime.datetime.strptime(element, "%Y").date()
+        if len(element) == 10 and element.count('-') == 2:
+            output = datetime.datetime.strptime(element, '%Y-%m-%d').date()
+        elif len(element) == 7 and element.count('-') == 1:
+            output = datetime.datetime.strptime(element, '%Y-%m').date()
+        elif len(element) == 4 and element.count('-') == 0:
+            output = datetime.datetime.strptime(element, '%Y').date()
         else:
             output = pyrfc3339.parse(element)
     elif tag == 'uuid':
@@ -137,21 +135,29 @@ def p_expression_tagged_element(p):
         output = _serializers[tag](element)
     else:
         raise NotImplementedError(
-            "Don't know how to handle tag ImmutableDict({})".format(tag))
+            u"Don't know how to handle tag ImmutableDict({})".format(tag))
 
     p[0] = output
 
 
 def p_error(p):
     if p is None:
-        raise SyntaxError("EOF Reached")
+        raise SyntaxError('EOF Reached')
     else:
         raise SyntaxError(p)
 
 
-def parse(text):
+def uparse(text):
     kwargs = ImmutableDict({})
     if __debug__:
-        kwargs = dict({"debug": True})
+        kwargs = dict({'debug': True})
     p = ply.yacc.yacc(**kwargs)
     return p.parse(text, lexer=lex())
+
+
+def parse(text, input_encoding = 'utf-8'):
+    if isinstance(text, unicode):
+        utext = text
+    else:
+        utext = text.decode(input_encoding)
+    return uparse(utext)
