@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 import datetime
 import pytz
 import unittest
@@ -56,6 +57,8 @@ class EdnTest(unittest.TestCase):
                        "true.")
         self.check_lex("[LexToken(SYMBOL,Symbol($:ABC?),1,0)]",
                        "$:ABC?")
+        self.check_lex("[LexToken(MAP_START,'{',1,0), LexToken(KEYWORD,Keyword(a),1,2), LexToken(BOOLEAN,False,1,5), LexToken(KEYWORD,Keyword(b),1,12), LexToken(BOOLEAN,False,1,15), LexToken(MAP_OR_SET_END,'}',1,21)]",
+                       "{ :a false, :b false }")
 
     def check_parse(self, expected_output, actual_input):
         self.assertEqual(expected_output, edn_parse.parse(actual_input))
@@ -67,12 +70,10 @@ class EdnTest(unittest.TestCase):
                          'a*b')
         self.check_parse("ab",
                          '"ab"')
-        self.check_parse("a\\\"b",
-                         '"a\\"b"')
+        self.check_parse('a"b',
+                         r'"a\"b"')
         self.check_parse("blah\n",
                          '"blah\n"')
-        self.check_parse("blah blah",
-                         '"blah\spaceblah"')
         self.check_parse([1, 2, 3],
                          "[1 2 3]")
         self.check_parse({1, 2, 3},
@@ -102,8 +103,10 @@ class EdnTest(unittest.TestCase):
                          '#inst "2011-10-09"')
         self.check_parse("|", "\"|\"")
         self.check_parse("%", "\"%\"")
-        self.check_parse(['bl\\"ah'], """["bl\\"ah"]""")
+        self.check_parse(['bl"ah'], r"""["bl\"ah"]""")
         self.check_parse("blah\n", '"blah\n"')
+        self.check_parse('"', r'"\""')
+        self.check_parse('\\', r'"\\"')
         self.check_parse(["abc", "123"], '["abc", "123"]')
         self.check_parse({"key": "value"}, '{"key" "value"}')
 
@@ -200,6 +203,7 @@ class EdnTest(unittest.TestCase):
 
         class TagDate(TaggedElement):
             def __init__(self, value):
+                super(TagDate, self).__init__()
                 self.name = 'date'
                 self.value = datetime.datetime.strptime(
                     value,
